@@ -7,5 +7,5 @@ from .core import (
     prefetch_github,
 )
 from .core.list_remote import ListRemote
-from .effect import detect_actual_hash_from_nix_output, dispatcher
+from .effects import detect_actual_hash_from_nix_output, dispatcher
 from .public import check_repository_is_dirty, nix_prefetch_github
