@@ -3,7 +3,7 @@ from effect import Effect
 from effect.do import do
 
 from nix_prefetch_github.core import GetCurrentDirectory, prefetch_directory
-from nix_prefetch_github.effect import perform_effects
+from nix_prefetch_github.effects import perform_effects
 
 
 @click.command("nix-prefetch-github-directory")
